@@ -152,10 +152,13 @@ def build_listener(
         hosts.append((connection_params.get("hostStandby"), connection_params.get("portStandby")))
     use_ssl = connection_params.get("use_ssl", False)
     ssl_version = connection_params.get("ssl_version", ssl.PROTOCOL_TLS)
-    logger.info(f"Use SSL? {use_ssl}. Version: {ssl_version}")
     outgoing_heartbeat = int(connection_params.get("outgoingHeartbeat", 0))
     incoming_heartbeat = int(connection_params.get("incomingHeartbeat", 0))
 
+    logger.info(
+        f"Use SSL? {use_ssl}. Version: {ssl_version}. Outgoing/Ingoing heartbeat: {outgoing_heartbeat}/{incoming_heartbeat}. Background? {should_process_msg_on_background}"
+    )
+
     if is_heartbeat_enabled(outgoing_heartbeat, incoming_heartbeat) and not should_process_msg_on_background:
         logger.warning(
             "STOMP heartbeat enabled while message processing on background is disable! "
